Package: pagedown
Type: Package
Title: Paginate the HTML Output of R Markdown with CSS for Print
Version: 0.25
Authors@R: c(
  person("Yihui", "Xie", role = c("aut", "cre"), email = "xie@yihui.name", comment = c(ORCID = "0000-0003-0645-5666")),
  person("Romain", "Lesur", role = c("aut", "cph"), comment = c(ORCID = "0000-0002-0721-5595")),
  person("Christophe", "Dervieux", role = c("ctb"), comment = c(ORCID = "0000-0003-4474-2498")),
  person("Brent", "Thorne", role = "aut", comment = c(ORCID = "0000-0002-1099-3857")),
  person("Xianying", "Tan", role = "aut", comment = c(ORCID = "0000-0002-6072-3521")),
  person("Atsushi", "Yasumoto", role = c("ctb"), comment = c(ORCID = "0000-0002-8335-495X")),
  person(given = "Posit Software, PBC", role = c("cph", "fnd")),
  person("Adam", "Hyde", role = "ctb", comment = "paged.js in resources/js/"),
  person("Min-Zhong", "Lu", role = "ctb", comment = "resume.css in resources/css/"),
  person("Zulko", role = "ctb", comment = "poster-relaxed.css in resources/css/"),
  person()
  )
Description: Use the paged media properties in CSS and the JavaScript
  library 'paged.js' to split the content of an HTML document into discrete
  pages. Each page can have its page size, page numbers, margin boxes, and
  running headers, etc. Applications of this package include books, letters,
  reports, papers, business cards, resumes, and posters.
Depends: R (>= 3.5.0)
Imports: rmarkdown (>= 2.13), bookdown (>= 0.8), htmltools, jsonlite,
        later (>= 1.0.0), processx, servr (>= 0.31), httpuv, xfun,
        websocket
Suggests: promises, testit, xaringan, pdftools, revealjs, covr, xml2
License: MIT + file LICENSE
URL: https://github.com/rstudio/pagedown
BugReports: https://github.com/rstudio/pagedown/issues
SystemRequirements: Pandoc (>= 2.2.3)
Encoding: UTF-8
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-08-27 15:43:53 UTC; yihui
Author: Yihui Xie [aut, cre] (ORCID: <https://orcid.org/0000-0003-0645-5666>),
  Romain Lesur [aut, cph] (ORCID:
    <https://orcid.org/0000-0002-0721-5595>),
  Christophe Dervieux [ctb] (ORCID:
    <https://orcid.org/0000-0003-4474-2498>),
  Brent Thorne [aut] (ORCID: <https://orcid.org/0000-0002-1099-3857>),
  Xianying Tan [aut] (ORCID: <https://orcid.org/0000-0002-6072-3521>),
  Atsushi Yasumoto [ctb] (ORCID: <https://orcid.org/0000-0002-8335-495X>),
  Posit Software, PBC [cph, fnd],
  Adam Hyde [ctb] (paged.js in resources/js/),
  Min-Zhong Lu [ctb] (resume.css in resources/css/),
  Zulko [ctb] (poster-relaxed.css in resources/css/)
Maintainer: Yihui Xie <xie@yihui.name>
Repository: CRAN
Date/Publication: 2026-08-28 07:20:09 UTC
