# Generated by roxygen2: do not edit by hand

export(book_crc)
export(business_card)
export(chrome_print)
export(find_chrome)
export(html_letter)
export(html_paged)
export(html_resume)
export(jss_paged)
export(poster_jacobs)
export(poster_relaxed)
export(thesis_paged)
import(stats)
import(utils)
