---
phone: "+1 844-448-1212"
email: "info@posit.co"
url: www.posit.co
address: |
  @rstudio
logo: "https://posit.co/wp-content/themes/Posit/dist/images/site-share-image.jpg"
person: 
  - name: Tareef Kawaf
    title: President of Posit Software, PBC
    repeat: 12
  - name: Yihui Xie
    title: Responsible for `r head(grep('(?<!shut)down$', unique(.packages(T)), value=T, perl=T), 2)`
    email: xie@yihui.name
    url: https://yihui.name
    repeat: 12
# googlefonts: "Righteous" # feel free to try other fonts at https://fonts.google.com
paperwidth: 8.5in
paperheight: 11in
cols: 4
rows: 3
output: pagedown::business_card
---

<!-- if you prefer you can create cards in markdown instead of YAML declaration -->

::: {.wrapper data-repeat="12"}
[Another Name]{slot="name"}
[Another Title]{slot="title"}
[someone@posit.co]{slot="email"}
:::


<!-- if you prefer black text on white background, set eval=TRUE on the chunk below -->

```{css, eval=FALSE}
.wrapper {
  color: black;
  background-color: white;
  border: 1px dotted black;
}
.coordinates {
  color: #333;
}
```
