---
title: "A letter of recommendation for Emi Tanaka"
author: "Yihui Xie"
output:
  pagedown::html_letter:
    self_contained: false
links-to-footnotes: true
paged-footnotes: true
# uncomment this line to produce HTML and PDF in RStudio:
#knit: pagedown::chrome_print
---

![The Posit logo](https://posit.co/wp-content/themes/Posit/dist/images/site-share-image.jpg){.logo}

::: from
Yihui Xie  
In the Middle of Nowhere  
Omaha, NE 68022  
Email: xie@yihui.name  
Homepage: https://yihui.name
:::


Hiring Manager  
School of Ninja, Hacker's University  
404 Not Found Road, Undefined 0x1234, NA

::: date
December 32, 2018
:::

Dear Hiring Manager,

It is my honor and pleasure to write a letter of recommendation^[Is this the first letter that contains GIFs ever in the history of human?] for Dr. Emi Tanaka, a great hacker in my eyes.

Emi said [it was heck of a praise](https://twitter.com/statsgen/status/1023118510745038848) when I said Earo was a very impressive hacker. Well, the fact is that I have been actually impressed many more times by Emi, which is probably because Earo is a relatively low-key hacker, and I have seen a lot of cool things Emi posted on Twitter this year. If I were to write a full letter about them, it would probably take me two whole days. Below is a one-hour attempt to show the many ways in which she can be so cool.

![The kunoichi theme for xaringan, made by Emi](https://github.com/emitanaka/ninja-theme/raw/master/docs/images/kunoichi-showcase.gif)

- She added the [ninja themes to **xaringan**](https://github.com/yihui/xaringan/pull/165).

- [The **anicon** package](https://twitter.com/statsgen/status/1021683550171496449) to insert animated icons or images or [text](https://twitter.com/statsgen/status/1010323499901075456) in R Markdown / **xaringan** / Shiny.

- [The **datalegreyar** package](https://twitter.com/statsgen/status/1018823773162618882) that uses a special typeface to represent data directly with text (which is an even smarter idea than sparklines). Magic.

- [She discovered the ultimate secret](https://twitter.com/statsgen/status/1012664098616590336) of the "Infinite Moon Reader" in **xaringan**: when an HTML page is automatically refreshed, the scroll position is preserved. This is extremely helpful when the document is long or has many pages, because otherwise you will have to scroll like crazy to the position where you last viewed. This feature is quite subtle and has been there for almost two years, and Emi was the first person (to my knowledge) who had discovered it and been excited about it.

- Obviously she is very good at hacking with CSS. [Look at her **xaringan** slides](https://twitter.com/statsgen/status/1009591310150299648) with the shiny (I mean sparkling) r-ladies theme, and the content is pretty good, too!

- [The joy over FiraCode](https://twitter.com/statsgen/status/993662737099079680) (as it was supported in RStudio).

- She wrote [one of the bestest **blogdown** tutorials](https://twitter.com/statsgen/status/993003327074926592) (the level of details is amazing).

- And [people truly appreciated](https://twitter.com/certifiedwaif/status/1029640487399915520) her **blogdown** seminar.

- Her website is one of the most beautiful websites I have seen. In particular, [everyone loved her showcase.](https://twitter.com/statsgen/status/990422351593406464) Did I mention that it was actually one of the four websites I highlighted [in the R Markdown book](https://bookdown.org/yihui/rmarkdown/basics-examples.html)?

- [The shiny custom loader.](https://twitter.com/statsgen/status/972727676459872256) Hahaha. [Super fun](https://twitter.com/statsgen/status/975321139550478336), and magic.

- [She can teach statistics courses.](https://twitter.com/statsgen/status/1001293550531694592) I barely remember what linear mixed models are.

- And [she just started answering](https://stackoverflow.com/a/51575804/559676) #rstats questions on Stack Overflow the other day! Thank you!!

Creative, enthusiastic, excellent taste of design, with great attention to details. That is my overall impression of this hacker.^[This letter was originally published in my blog at https://yihui.name/en/2018/07/emi-tanaka/.]

![The hacker's way of parking](https://slides.yihui.name/gif/impossible-parking.gif)

![Yihui's signature](https://user-images.githubusercontent.com/163582/47831497-c6656c00-dd5e-11e8-87b3-1f03fa97baa0.png)  
Yihui Xie  
Software Engineer  
RStudio, PBC
